@@ -1,10 +1,12 @@
 <?php
-function thumbnail ($valor)
+function thumbnail ($galeria,$valor)
 {
 
-# FitGallery copyleft GPL Pollo y Presi 0.62 JPEG-JPEG 
+# FitGallery 0.75 copyleft GPL Pollo (magura@ardilla.dyndns.org) y Presi (presi@confluencia.net)
 
-$rutathumbs="thumbs";
+$horiz=120;
+$dirgal="."."/".basename($galeria);
+$rutathumbs=$dirgal."/"."thumbs";
 $fichero=basename($valor);
 $imagenthumb=$rutathumbs."/".$fichero;
 header("Content-type: image/jpeg");
@@ -16,13 +18,13 @@ if (file_exists($imagenthumb))
 }
 else
 {
-  $rutaimgs="imgs";
+  $rutaimgs=$dirgal."/"."imgs";
   $imagen=$rutaimgs."/".$fichero;
 
   $size=getimagesize("$imagen");
 
-  $new_w=120*$size[0]/$size[1];
-  $new_h=120;
+  $new_w=$horiz*$size[0]/$size[1];
+  $new_h=$horiz;
 
   $dst_img=ImageCreateTrueColor($new_w,$new_h);
   $src_img=ImageCreateFromJpeg($imagen);
@@ -36,6 +38,6 @@ else
 
 }
 
-thumbnail ($_GET["valor"]);
+thumbnail ($_GET["galeria"],$_GET["valor"]);
 
 ?>
